@@ -11,53 +11,43 @@ MagnavoxDVD1::MagnavoxDVD1(
       Magnavox_Make,
       index)
 {
-  RC6Protocol *rp = new RC6Protocol(
-    guiObject,
-    index,
-    457, 435,
-    107380, true);
+  addControlledDevice(Magnavox_Make, "MDV450", DVD_Device);
 
-  threadableProtocol = rp;
+  threadableProtocol = new RC6Protocol(guiObject, index, 0x04);
 
-  rp->setHeaderPair(2698, 870);
-
-  rp->setToggleBit(5);
-
-  setPreData(0xEFB, 13);
-
-  addKey("power", Power_Key, 0xF3, 8);
-  addKey("1", One_Key, 0xFE, 8);
-  addKey("2", Two_Key, 0xFD, 8);
-  addKey("3", Three_Key, 0xFC, 8);
-  addKey("4", Four_Key, 0xFB, 8);
-  addKey("5", Five_Key, 0xFA, 8);
-  addKey("6", Six_Key, 0xF9, 8);
-  addKey("7", Seven_Key, 0xF8, 8);
-  addKey("8", Eight_Key, 0xF7, 8);
-  addKey("9", Nine_Key, 0xF6, 8);
-  addKey("0", Zero_Key, 0xFF, 8);
-  addKey("title", DiscTitle_Key, 0x7C, 8);
-  addKey("display", Info_Key, 0xF0, 8);
-  addKey("disc_Menu", DiscMenu_Key, 0xAB, 8);
-  addKey("system_menu", Menu_Key, 0x7D, 8);
-  addKey("^", Up_Key, 0xA7, 8);
-  addKey("<", Left_Key, 0xA5, 8);
-  addKey(">", Right_Key, 0xA4, 8);
-  addKey("v", Down_Key, 0xA6, 8);
-  addKey("ok", Select_Key, 0xA3, 8);
-  addKey("<<", Rewind_Key, 0xDE, 8);
-  addKey(">>", FastForward_Key, 0xDF, 8);
-  addKey("stop", Stop_Key, 0xCE, 8);
-  addKey("play", Play_Key, 0xD3, 8);
-  addKey("pause", Pause_Key, 0xCF, 8);
-  addKey("subtitle", Captions_Key, 0xB4, 8);
-  addKey("angle", Unmapped_Key, 0x7A, 8);
-  addKey("zoom", Unmapped_Key, 0x08, 8);
-  addKey("audio", Unmapped_Key, 0xB1, 8);
-  addKey("repeat", Unmapped_Key, 0xE2, 8);
-  addKey("a-b", Unmapped_Key, 0xC4, 8);
-  addKey("preview", Unmapped_Key, 0x2A, 8);
-  addKey("mute", Mute_Key, 0xF2, 8);
+  addKey("power", Power_Key, 0x0C, 8);
+  addKey("1", One_Key, 0x01, 8);
+  addKey("2", Two_Key, 0x02, 8);
+  addKey("3", Three_Key, 0x03, 8);
+  addKey("4", Four_Key, 0x04, 8);
+  addKey("5", Five_Key, 0x05, 8);
+  addKey("6", Six_Key, 0x06, 8);
+  addKey("7", Seven_Key, 0x07, 8);
+  addKey("8", Eight_Key, 0x08, 8);
+  addKey("9", Nine_Key, 0x09, 8);
+  addKey("0", Zero_Key, 0x00, 8);
+  addKey("title", DiscTitle_Key, 0x83, 8);
+  addKey("display", Info_Key, 0x0F, 8);
+  addKey("disc_Menu", DiscMenu_Key, 0x54, 8);
+  addKey("system_menu", Menu_Key, 0x82, 8);
+  addKey("^", Up_Key, 0x58, 8);
+  addKey("<", Left_Key, 0x5A, 8);
+  addKey(">", Right_Key, 0x5B, 8);
+  addKey("v", Down_Key, 0x5C, 8);
+  addKey("ok", Select_Key, 0x5D, 8);
+  addKey("<<", Rewind_Key, 0x21, 8);
+  addKey(">>", FastForward_Key, 0x20, 8);
+  addKey("stop", Stop_Key, 0x31, 8);
+  addKey("play", Play_Key, 0x2C, 8);
+  addKey("pause", Pause_Key, 0x30, 8);
+  addKey("subtitle", Captions_Key, 0x4B, 8);
+  addKey("angle", Unmapped_Key, 0x85, 8);
+  addKey("zoom", Unmapped_Key, 0xF7, 8);
+  addKey("audio", Unmapped_Key, 0x4E, 8);
+  addKey("repeat", Unmapped_Key, 0x1D, 8);
+  addKey("a-b", Unmapped_Key, 0x3B, 8);
+  addKey("preview", Unmapped_Key, 0xD5, 8);
+  addKey("mute", Mute_Key, 0x0D, 8);
 }
 
 
@@ -69,16 +59,7 @@ MagnavoxVCR1::MagnavoxVCR1(
       Magnavox_Make,
       index)
 {
-  RC5Protocol *rp = new RC5Protocol(
-    guiObject,
-    index,
-    900, 900,
-    900,
-    113800, true);
-
-  threadableProtocol = rp;
-
-  rp->setToggleBit(2);
+  threadableProtocol = new RC5Protocol(guiObject, index);
 
   addKey("Power", Power_Key, 0x114C, 13);
   addKey("0", Zero_Key, 0x1140, 13);
@@ -130,7 +111,7 @@ MagnavoxVCR1::MagnavoxVCR1(
   addKey("VarSlowDn", Unmapped_Key, 0x1165, 13);
   addKey("Qtr", Unmapped_Key, 0x1167, 13);
   addKey("TrackUp", TrackingPlus_Key, 0x014D, 13);
-  addKey("TrackDn", TrackingMinus_key, 0x014E, 13);
+  addKey("TrackDn", TrackingMinus_Key, 0x014E, 13);
   addKey("GoTo", Unmapped_Key, 0x1173, 13);
   addKey("Memo", Unmapped_Key, 0x117B, 13);
   addKey("Speed", VHSSpeed_Key, 0x117A, 13);
@@ -143,11 +124,15 @@ MagnavoxConverterBox1::MagnavoxConverterBox1(
   QObject *guiObject,
   unsigned int index)
   : PIRKeysetMetaData(
-      "Digital Converter Box Keyset 1",
+      "Settop Box Keyset 1",
       Magnavox_Make,
       index)
 {
+  addControlledDevice(Magnavox_Make, "TB100MG9", TV_Device);
+
   NECProtocol *np = new NECProtocol(
+    guiObject,
+    index,
     894, 795,
     894, 2537,
     33751, false);
@@ -194,45 +179,34 @@ MagnavoxTV1::MagnavoxTV1(
       Magnavox_Make,
       index)
 {
-  RC5Protocol *rp = new RC5Protocol(
-    guiObject,
-    index,
-    903, 876,
-    937,
-    113409, true);
+  threadableProtocol = new RC5Protocol(guiObject, index, 0x40);
 
-  threadableProtocol = rp;
-
-  rp->setToggleBit(2);
-
-  setPreData(0x10, 5);
-
-  addKey("Power", Power_Key, 0x0C, 8);
-  addKey("Reset", Reset_Key, 0x0E, 8);
-  addKey("Sleep", Sleep_Key, 0x26, 8);
-  addKey("Mute", Mute_Key, 0x0D, 8);
-  addKey("VolUp", VolumeUp_Key, 0x10, 8);
-  addKey("VolDown", VolumeDown_Key, 0x11, 8);
-  addKey("ChUp", ChannelUp_Key, 0x20, 8);
-  addKey("ChDown", ChannelDown_Key, 0x21, 8);
-  addKey("PrevCh", PrevChannel_Key, 0x21, 8);
-  addKey("One", One_Key, 0x01, 8);
-  addKey("Two", Two_Key, 0x02, 8);
-  addKey("Three", Three_Key, 0x03, 8);
-  addKey("Four", Four_Key, 0x04, 8);
-  addKey("Five", Five_Key, 0x05, 8);
-  addKey("Six", Six_Key, 0x06, 8);
-  addKey("Seven", Seven_Key, 0x07, 8);
-  addKey("Eight", Eight_Key, 0x08, 8);
-  addKey("Nine", Nine_Key, 0x09, 8);
-  addKey("Zero", Zero_Key, 0x00, 8);
-  addKey("Display", Info_Key, 0x2E, 8);
-  addKey("Plus", Right_Key, 0x2B, 8);
-  addKey("Minus", Left_Key, 0x2C, 8);
-  addKey("Status", Unmapped_Key, 0x0F, 8);
-  addKey("Play", Play_Key, 0x1C, 8);
-  addKey("Stop", Stop_Key, 0x1D, 8);
-  addKey("FF", FastForward_Key, 0x2B, 8);
-  addKey("Rev", Rewind_Key, 0x2C, 8);
-  addKey("Pause", Pause_Key, 0x3B, 8);
+  addKey("Power", Power_Key, 0x0C, 6);
+  addKey("Reset", Reset_Key, 0x0E, 6);
+  addKey("Sleep", Sleep_Key, 0x26, 6);
+  addKey("Mute", Mute_Key, 0x0D, 6);
+  addKey("VolUp", VolumeUp_Key, 0x10, 6);
+  addKey("VolDown", VolumeDown_Key, 0x11, 6);
+  addKey("ChUp", ChannelUp_Key, 0x20, 6);
+  addKey("ChDown", ChannelDown_Key, 0x21, 6);
+  addKey("PrevCh", PrevChannel_Key, 0x21, 6);
+  addKey("One", One_Key, 0x01, 6);
+  addKey("Two", Two_Key, 0x02, 6);
+  addKey("Three", Three_Key, 0x03, 6);
+  addKey("Four", Four_Key, 0x04, 6);
+  addKey("Five", Five_Key, 0x05, 6);
+  addKey("Six", Six_Key, 0x06, 6);
+  addKey("Seven", Seven_Key, 0x07, 6);
+  addKey("Eight", Eight_Key, 0x08, 6);
+  addKey("Nine", Nine_Key, 0x09, 6);
+  addKey("Zero", Zero_Key, 0x00, 6);
+  addKey("Display", Info_Key, 0x2E, 6);
+  addKey("Plus", Right_Key, 0x2B, 6);
+  addKey("Minus", Left_Key, 0x2C, 6);
+  addKey("Status", Unmapped_Key, 0x0F, 6);
+  addKey("Play", Play_Key, 0x1C, 6);
+  addKey("Stop", Stop_Key, 0x1D, 6);
+  addKey("FF", FastForward_Key, 0x2B, 6);
+  addKey("Rev", Rewind_Key, 0x2C, 6);
+  addKey("Pause", Pause_Key, 0x3B, 6);
 }
