@@ -20,10 +20,10 @@ MitsubishiTV1::MitsubishiTV1(
 
   np->setTrailerPulse(300);
 
-  np->setPreData(0xE2, 8);
-
 //  np->setMinimumRepetitions(1);
 
+  setPreData(0xE2, 8);
+
   addKey("POWER", Power_Key, 0x40, 8);
   addKey("0", Zero_Key, 0x90, 8);
   addKey("1", One_Key, 0x00, 8);
@@ -124,10 +124,10 @@ MitsubishiVCR1::MitsubishiVCR1(
 
   np->setTrailerPulse(300);
 
-  np->setPreData(0xEA, 8);
-
 //  np->setMinimumRepetitions(1);
 
+  setPreData(0xEA, 8);
+
   addKey("POWER", Power_Key, 0x40, 8);
   addKey("CH-", ChannelDown_Key, 0x48, 8);
   addKey("CH+", ChannelUp_Key, 0x50, 8);
