@@ -15,6 +15,7 @@ enum PIRMakeName{
   Hitachi_Make,
   JVC_Make,
   LG_Make,
+  Magnavox_Make,
   Mitsubishi_Make,
   Nokia_Make,
   Panasonic_Make,
@@ -27,6 +28,7 @@ enum PIRMakeName{
   Sanyo_Make,
   Sharp_Make,
   Sony_Make,
+  Tivo_Make,
   Toshiba_Make,
   Westinghouse_Make,
   Yamaha_Make,
